@@ -19,18 +19,21 @@
 
 #pragma once
 
-#include "Tool.h"
+#include "ToolGcc.h"
 
 namespace cs::semantic {
 
-    struct ToolClang : public Tool {
-        [[nodiscard]]
-        const char* name() const override;
+    struct ToolClang : public ToolGcc {
+
+        ToolClang() noexcept;
 
         [[nodiscard]]
-        bool recognize(const fs::path& program) const override;
+        rust::Result<SemanticPtr> recognize(const Execution &execution) const override;
 
+    protected:
         [[nodiscard]]
-        rust::Result<SemanticPtrs> compilations(const Execution &execution) const override;
+        bool is_compiler_call(const fs::path &program) const override;
+
+        const FlagsByName flag_definition;
     };
 }
