@@ -20,17 +20,25 @@
 #pragma once
 
 #include "Tool.h"
+#include "Parsers.h"
 
 namespace cs::semantic {
 
     struct ToolGcc : public Tool {
-        [[nodiscard]]
-        const char* name() const override;
 
         [[nodiscard]]
-        bool recognize(const fs::path& program) const override;
+        rust::Result<SemanticPtr> recognize(const Execution &execution) const override;
+
+    protected:
+        [[nodiscard]]
+        virtual bool is_compiler_call(const fs::path& program) const;
 
         [[nodiscard]]
-        rust::Result<SemanticPtrs> compilations(const Execution &execution) const override;
+        virtual rust::Result<SemanticPtr> compilation(const Execution &execution) const;
+
+        [[nodiscard]]
+        static rust::Result<SemanticPtr> compilation(const FlagsByName &flags, const Execution &execution);
+
+        static const FlagsByName FLAG_DEFINITION;
     };
 }
