@@ -19,18 +19,30 @@
 
 #pragma once
 
-#include "Tool.h"
+#include "ToolGcc.h"
+
+#include <list>
+#include <string>
+
+namespace el {
+    class Resolver;
+}
 
 namespace cs::semantic {
 
-    struct ToolWrapper : public Tool {
+    struct ToolWrapper : public ToolGcc {
         [[nodiscard]]
-        const char* name() const override;
+        rust::Result<SemanticPtr> recognize(const Execution &execution) const override;
 
-        [[nodiscard]]
-        bool recognize(const fs::path& program) const override;
+    // visible for testing
+    public:
+        static bool is_ccache_call(const fs::path &program);
+        static bool is_ccache_query(const std::list<std::string> &arguments);
 
-        [[nodiscard]]
-        rust::Result<SemanticPtrs> compilations(const Execution &execution) const override;
+        static bool is_distcc_call(const fs::path &program);
+        static bool is_distcc_query(const std::list<std::string> &arguments);
+
+        static domain::Execution remove_wrapper(const domain::Execution &);
+        static domain::Execution remove_wrapper(el::Resolver &, const domain::Execution &);
     };
 }
