@@ -19,6 +19,8 @@
 
 #pragma once
 
+#include "config.h"
+
 namespace ps {
 
     struct ApplicationLogConfig {
@@ -31,6 +33,8 @@ namespace ps {
         void record(const char** argv, const char** envp) const;
         void context() const;
 
+        NON_DEFAULT_CONSTRUCTABLE(ApplicationLogConfig);
+
     protected:
         const char *name_;
         const char *id_;
