@@ -19,6 +19,7 @@
 
 #pragma once
 
+#include "config.h"
 #include <csignal>
 
 namespace sys {
@@ -27,18 +28,15 @@ namespace sys {
 
     class SignalForwarder {
     public:
-        explicit SignalForwarder(Process& child);
+        explicit SignalForwarder(const Process &child) noexcept;
         ~SignalForwarder() noexcept;
 
     public:
-        SignalForwarder() = delete;
-        SignalForwarder(const SignalForwarder&) = delete;
-        SignalForwarder(SignalForwarder&&) noexcept = delete;
-
-        SignalForwarder& operator=(const SignalForwarder&) = delete;
-        SignalForwarder& operator=(SignalForwarder&&) noexcept = delete;
+        NON_DEFAULT_CONSTRUCTABLE(SignalForwarder);
+        NON_COPYABLE_NOR_MOVABLE(SignalForwarder);
 
     private:
+        pid_t pid_;
         using handler_t = void (*)(int);
         handler_t handlers_[NSIG];
     };
